#!/bin/bash

./update.pl --pot
echo ""
./abi-extract.pl -N gl-ES
./abi-extract.pl -N nb-NO
./abi-extract.pl -N sv-SE
./abi-extract.pl -N de-DE
./abi-extract.pl -N hu-HU
./abi-extract.pl -N uk-UA 
./abi-extract.pl -N ca-ES 
./abi-extract.pl -N nl-NL 
./abi-extract.pl -N id-ID 
./abi-extract.pl -N pl-PL 
./abi-extract.pl -N zh-CN 
./abi-extract.pl -N cs-CZ 
./abi-extract.pl -N es-ES 
./abi-extract.pl -N it-IT      
./abi-extract.pl -N pt-BR 
./abi-extract.pl -N zh-TW 
./abi-extract.pl -N cy-CY 
./abi-extract.pl -N fi-FI 
./abi-extract.pl -N lt-LT 
./abi-extract.pl -N pt-PT 
./abi-extract.pl -N da-DK 
./abi-extract.pl -N fr-FR 
./abi-extract.pl -N nn-NO 
./abi-extract.pl -N ru-RU 
./abi-extract.pl -N bg-BG
./abi-extract.pl -N tr-TR
./abi-extract.pl -N de-CH
./abi-extract.pl -N ta-IN
./abi-extract.pl -N qu-BO
./abi-extract.pl -N ast-ES
./abi-extract.pl -N ku

./update.pl gl-ES
./update.pl nb-NO
./update.pl sv-SE
./update.pl de-DE
./update.pl hu-HU
./update.pl uk-UA 
./update.pl ca-ES 
./update.pl nl-NL 
./update.pl id-ID 
./update.pl pl-PL 
./update.pl zh-CN 
./update.pl cs-CZ 
./update.pl es-ES 
./update.pl it-IT      
./update.pl pt-BR 
./update.pl zh-TW 
./update.pl cy-CY 
./update.pl fi-FI 
./update.pl lt-LT 
./update.pl pt-PT 
./update.pl da-DK 
./update.pl fr-FR 
./update.pl nn-NO 
./update.pl ru-RU 
./update.pl bg-BG 
./update.pl tr-TR
./update.pl de-CH
./update.pl ta-IN
./update.pl qu-BO
./update.pl ast-ES
./update.pl ku

